@@ -11,7 +11,7 @@ fit2 <- lm(Income ~ HSGrad*o70, data = states)
 fitw <- lm(Income ~ HSGrad*Murder*Illiteracy, data = states, weights = wts)
 
 
-library(survey, quietly = TRUE)
+suppressMessages(library(survey, quietly = TRUE))
 data(api)
 dstrat <- svydesign(id=~1,strata=~stype, weights=~pw, data=apistrat, fpc=~fpc)
 regmodel <- svyglm(api00~ell*meals*both,design=dstrat)
